Introduction
============

Philosophy
----------

WireTransfers is being developed while keeping a few :pep:`20` idioms in mind:

#. Beautiful is better than ugly.
#. Explicit is better than implicit.
#. Simple is better than complex.
#. Complex is better than complicated.
#. Readability counts.

Therefore all contributions to WireTransfers should keep these important
words in mind.

.. _`isc`:

ISC License
-----------

WireTransfers is released under the terms of `The ISC License`_.

*"Why the ISC license?"*, you may ask? That's because this license allows
software to be used freely in proprietary, closed-source software.

.. _`The ISC License`: http://www.opensource.org/licenses/isc-license

WireTransfers License
---------------------

    .. include:: ../../LICENSE
